package cn.com.ty.lift.business.library.controller;

import cn.com.ty.lift.business.library.dao.entity.Lift;
import cn.com.ty.lift.business.library.dao.entity.ProjectLiftRelevance;
import cn.com.ty.lift.business.library.dao.entity.model.BatchUpdateLiftRequest;
import cn.com.ty.lift.business.library.dao.entity.model.SelectBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.dao.entity.model.LiftRequest;
import cn.com.ty.lift.business.library.dao.entity.model.UpdateBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.service.LibraryService;
import cn.com.ty.lift.business.library.service.PlatformCompanyLiftRelevanceService;
import cn.com.ty.lift.business.library.service.ProjectLiftRelevanceService;
import cn.com.ty.lift.common.base.ExportRequest;
import cn.com.xwy.boot.web.dto.RestResponse;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;

/**
 * @author bieao
 * @date 2019/11/27
 * @description 电梯档案控制层
 */
@RestController
@RequestMapping("library")
public class LibraryController {

    @Resource
    private LibraryService libraryService;

    @Resource
    private ProjectLiftRelevanceService projectRelevanceService;

    @Resource
    private PlatformCompanyLiftRelevanceService platformService;

    /**
     * @param request 电梯列表查询条件
     * @return RestResponse 电梯分页列表结果
     * @description 查询电梯列表
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("list")
    public RestResponse list(@RequestBody LiftRequest request) {
        return libraryService.list(request);
    }

    /**
     * @param id 电梯id
     * @return RestResponse 电梯详情
     * @description 查询电梯详情
     * @date 2019/12/6 10:51 AM
     */
    @PostMapping("detail/{id}")
    public RestResponse detail(@PathVariable(name = "id") Long id) {
        return libraryService.detail(id);
    }

    /**
     * @param lift 新增电梯数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 新增电梯
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("add")
    public RestResponse add(@RequestBody Lift lift) {
        return libraryService.add(lift);
    }

    /**
     * @param lift 修改电梯数据项
     * @return 1.成功, 0.失败, 消息描述
     * @description 修改电梯
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("modify")
    public RestResponse modify(@RequestBody Lift lift) {
        return libraryService.modify(lift);
    }

    /**
     * @param request updateLiftList 项目id列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 电梯批量锁定、解锁
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("lockOrUnlock")
    public RestResponse lockOrUnlock(@RequestBody BatchUpdateLiftRequest request) {
        return projectRelevanceService.lockOrUnlock(request);
    }

    /**
     * @param projectLiftRelevance 关联表主键id
     * @return 1.成功, 0.失败, 消息描述
     * @description 逻辑删除电梯
     * @date 2019/11/27 10:03 AM
     */
    @PostMapping("logicDelete")
    public RestResponse logicDelete(@RequestBody ProjectLiftRelevance projectLiftRelevance) {
        return projectRelevanceService.logicDelete(projectLiftRelevance);
    }

    /**
     * @param request liftIdList 电梯id列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 批量查询电梯状态
     * @date 2019/12/5 5:24 PM
     */
    @PostMapping("selectBatchByIds")
    public RestResponse selectBatchByIds(@RequestBody SelectBatchPlatformCompanyRequest request) {
        return platformService.selectBatch(request);
    }

    /**
     * @param request companyLiftRelevanceList 公司电梯更新列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 批量更新电梯状态为停保
     * @date 2019/12/5 5:24 PM
     */
    @PostMapping("updateBatchByIds")
    public RestResponse updateBatchByIds(@RequestBody UpdateBatchPlatformCompanyRequest request) {
        return platformService.updateBatch(request);
    }

    /**
     * @param request 导出电梯数据列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 导出电梯
     * @date 2019/11/28 2:19 PM
     */
    @PostMapping("export")
    public void export(@RequestBody ExportRequest request) {
        libraryService.export(request);
    }
}
