package cn.com.ty.lift.business.library.service;

import cn.com.ty.lift.business.framework.util.MessageUtils;
import cn.com.ty.lift.business.library.dao.entity.LiftExtension;
import cn.com.ty.lift.business.library.dao.entity.PlatformCompanyLiftRelevance;
import cn.com.ty.lift.business.library.dao.entity.model.SelectBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.dao.entity.model.UpdateBatchPlatformCompanyRequest;
import cn.com.ty.lift.business.library.dao.mapper.PlatformCompanyLiftRelevanceMapper;
import cn.com.ty.lift.common.constants.ApiConstants;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;

/**
 * @author bieao
 * @date 2019/12/5
 * @description 平台企业电梯关联业务层
 */
@Service
public class PlatformCompanyLiftRelevanceService extends ServiceImpl<PlatformCompanyLiftRelevanceMapper, PlatformCompanyLiftRelevance> {

    @Resource
    private PlatformCompanyLiftRelevanceMapper mapper;

    /**
     * @param extension
     * @return PlatformCompanyLiftRelevance
     * @description 新增平台企业关联表数据
     * @date 2019/12/5 2:38 PM
     */
    public PlatformCompanyLiftRelevance save(LiftExtension extension) {
        PlatformCompanyLiftRelevance companyLiftEntry = new PlatformCompanyLiftRelevance();
        companyLiftEntry.setLiftId(extension.getId());
        companyLiftEntry.setCompanyId(extension.getMtCompanyId());
        if (save(companyLiftEntry)) {
            return companyLiftEntry;
        }
        return null;
    }

    /**
     * @param request liftIdList 电梯id列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 批量查询电梯状态
     * @date 2019/12/5 5:24 PM
     */
    public RestResponse selectBatch(SelectBatchPlatformCompanyRequest request) {
        List<PlatformCompanyLiftRelevance> list = mapper.selectBatchIds(request.getLiftIdList());
        if (!list.isEmpty()) {
            return RestResponse.error(ApiConstants.RESULT_NO_DATA, MessageUtils.get("msg.data.empty"));
        }
        return RestResponse.ok(list, ApiConstants.RESULT_SUCCESS, "msg.query.success");
    }

    /**
     * @param request companyLiftRelevanceList 公司电梯更新列表
     * @return 1.成功, 0.失败, 消息描述
     * @description 批量更新电梯状态为停保 TODO 清除维保计划
     * @date 2019/12/5 5:24 PM
     */
    public RestResponse updateBatch(UpdateBatchPlatformCompanyRequest request) {
        boolean result = updateBatchById(request.getCompanyLiftRelevanceList());
        if (!result) {
            return RestResponse.error(ApiConstants.RESULT_ERROR, MessageUtils.get("msg.modify.batch.fail"));
        }
        return RestResponse.ok(null, ApiConstants.RESULT_SUCCESS, "msg.modify.batch.success");
    }
}
