package cn.com.ty.lift.enterprise.custom.controller;

import cn.com.ty.lift.enterprise.custom.dao.entity.PropertyCompany;
import cn.com.ty.lift.enterprise.custom.dao.entity.model.PropertyCompanyReq;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyCompanyServiceImpl;
import cn.com.ty.lift.enterprise.custom.service.impl.PropertyContactServiceImpl;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import lombok.AllArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

@RestController
@RequestMapping("/property-company")
@AllArgsConstructor
/**
 * @author wang-hai-cheng
 * @date 2019/11/27
 * @description
 * 客户接口(物业公司)(甲方公司) 前端控制器
 */
public class PropertyCompanyController {
    private final PropertyCompanyServiceImpl propertyCompanyService;

    @GetMapping("/{id}")
    /**
     * @description 根据id获取客户详细信息
     * @date 2019/11/27 11:36
     * @param [客户id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompany(@PathVariable Long id) {
        PropertyCompany byId = propertyCompanyService.getById(id);
        if (byId == null) {
            return RestResponse.ok(null, "9", "无数据");
        }
        return RestResponse.ok(byId, "1", "查询成功");
    }

    @PostMapping("/list")
    /**
     * @description 根据条件查询客户列表
     * @date 2019/12/3 8:51
     * @param [客户名称或客户地址或客户邮寄地址或客户联系方式,页码,页大小,维保公司id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse propertyCompanies(@RequestBody PropertyCompanyReq propertyCompany) {
        return propertyCompanyService.propertyCompanies(propertyCompany);
    }

    @PostMapping("/add")
    /**
     * @description 新增客户
     * @date 2019/11/27 11:45
     * @param [客户]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse add(@RequestBody PropertyCompany propertyCompany) {
        //service层判断了是否有相同名称的name//如果数据库客户名不重复，就删除里面判断name是否重复的逻辑
        if (propertyCompanyService.save(propertyCompany)) {
            return RestResponse.ok(null,"1","新增成功");
        }
        return RestResponse.ok(null,"0","新增失败");
    }

    @PostMapping("/update")
    /**
     * @description 更新客户信息
     * @date 2019/11/27 11:45
     * @param [客户]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse update(@RequestBody PropertyCompany propertyCompany) {
        if (propertyCompanyService.updateById(propertyCompany)) {
            return RestResponse.ok(null, "1", "更新成功");
        }
        return RestResponse.ok(null, "0", "更新失败");
    }

    @PostMapping("/delete")
    /**
     * @description RestResponse
     * @date 2019/11/27 11:46
     * @param [id]
     * @return cn.com.xwy.boot.web.dto.RestResponse
     */
    public RestResponse delete(@RequestBody PropertyCompany propertyCompany) {
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //判断维保电梯台数是否为0
        //也就是客户公司创建的所有项目的总电梯的在保电梯是否为0

        return propertyCompanyService.delete(propertyCompany.getId());
    }

    @PostMapping("/project")
    public RestResponse project(@RequestBody PropertyCompany propertyCompany) {
        propertyCompany.getId();
        propertyCompany.getStatus();
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        //分页查询正在服务的项目列表
        List<HashMap<String, Object>> request = new ArrayList<>();
        HashMap<String, Object> map = new HashMap<>();
//        map.put("projectStatus",1);
//        request.add("")
//        restTemplate.postForEntity("http://132.232.206.88/project/list",)
//        Map<String, Object> map = new HashMap<>();
        map.put("项目编号", "1");
        map.put("项目名称", "1");
        map.put("项目地址", "1");
        map.put("在保台量", "1");
        map.put("开始时间", "1");
        map.put("结束时间", "1");
        map.put("甲方项目负责人", "1");
        map.put("甲方联系电话", "1");
        return RestResponse.ok(map, "待实现");
    }

    @PostMapping("/project/customs")
    public RestResponse customs(@RequestBody PropertyCompany propertyCompany) {
        List<PropertyCompany> propertyCompanies = propertyCompanyService.list(new QueryWrapper<PropertyCompany>()
                .select("id", "name")
                .eq("mt_company_id", propertyCompany.getMtCompanyId()));
        if (propertyCompanies.isEmpty()) {
            return RestResponse.ok(null, "9", "无数据");
        }
        return RestResponse.ok(propertyCompanies, "1", "查询成功");
    }
}