package cn.com.ty.lift.enterprise.oa.controller;

import cn.com.ty.lift.enterprise.common.RestResult;
import cn.com.ty.lift.enterprise.oa.entity.Announcement;
import cn.com.ty.lift.enterprise.oa.service.AnnouncementService;
import cn.com.xwy.boot.web.dto.RestResponse;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 公司公告
 */
@Slf4j
@RestController
@RequestMapping("announcement")
public class AnnouncementController {
    @Autowired
    private AnnouncementService announcementService;

    /**
     * @description 根据id查找公告
     * @date 2019/12/6 9:24
     * @param
     * @return
     */
    @PostMapping("findOne")
    public RestResponse<Announcement> findOne(Long id) {
        log.info("id: " + id);
        Announcement entity = announcementService.getById(id);
        return RestResult.okData(entity);
    }

    /**
     * @description 根据条件查找公告
     * @date 2019/12/6 9:24
     * @param
     * @return
     */
    @PostMapping("list")
    public RestResponse<IPage<Announcement>> list(int pageNum, int pageSize, Long mtCompanyId){
        IPage<Announcement> results = announcementService.selectByCondition(pageNum,pageSize,mtCompanyId);
        if(null == results){
            return RestResult.errException();
        }
        return RestResult.okData(results);
    }

    /**
     * @description 添加公告
     * @date 2019/12/6 9:25
     * @param
     * @return
     */
    @PostMapping("add")
    public RestResponse<Object> add(Announcement entity){
        if(null == entity){
            return RestResult.errParam();
        }
        boolean result = announcementService.save(entity);

        return RestResult.okData(result);
    }

    /**
     * @description 根据id删除公告
     * @date 2019/12/6 9:25
     * @param
     * @return
     */
    @PostMapping("delete")
    public RestResponse<Boolean> delete(Long id){
        boolean result = announcementService.removeById(id);
        return RestResult.okData(result);
    }
}
